@@ -106,7 +106,7 @@ class DefaultedDict(SuperDict):
         return tuple(self._lists)
 
     @property
-    def default_order(self) -> tuple[str]:
+    def default_order(self) -> tuple[str, ...]:
         """Default order of keys. Not changable."""
         return tuple(self._default_order)
 
