@@ -470,7 +470,7 @@ class SignPrinterLaTeX:
             "SecondaryName": sanitize_latex_code(english),
             "location": sanitize_latex_code(
                 str(thing.location.long_name)
-                if thing.sign.get("location_long", False)
+                if thing.sign.get("location_long", True)
                 else str(thing.where)
             ),
             "height": height,
